pub struct DiscardedPacket {
pub sequence_number: u32,
pub ds_class: u32,
pub ds_index: u32,
pub drops: u32,
pub input: u32,
pub output: u32,
pub reason: u32,
pub records: Vec<FlowRecord>,
}Expand description
Discarded packet notification sample (enterprise=0, format=5).
Reports packets discarded by the switch, along with the reason and flow records describing the discarded packet.
Fields
sequence_number: u32ds_class: u32ds_index: u32drops: u32input: u32output: u32reason: u32records: Vec<FlowRecord>Trait Implementations
Sourceimpl Clone for DiscardedPacket
impl Clone for DiscardedPacket
Sourcefn clone(&self) -> DiscardedPacket
fn clone(&self) -> DiscardedPacket
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscardedPacket
impl Debug for DiscardedPacket
Sourceimpl<'de> Deserialize<'de> for DiscardedPacket
impl<'de> Deserialize<'de> for DiscardedPacket
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DiscardedPacket
impl PartialEq for DiscardedPacket
Sourceimpl Serialize for DiscardedPacket
impl Serialize for DiscardedPacket
impl Eq for DiscardedPacket
impl StructuralPartialEq for DiscardedPacket